@@ -23,14 +23,16 @@
  */
 
 #include <stdio.h>
+#include <string.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <time.h>
 #include <dirent.h>
 #define __DO_NOT_DEFINE_COMPILE
-#include <regexp.h>
+#include <regex.h>
 #include <inttypes.h>
 #include <stdint.h>
+#include <signal.h>
 #include <sys/stat.h>
 #include <sys/time.h>
 #include <sys/utsname.h>
@@ -198,10 +200,10 @@ void tape_check_tapes_and_realloc(void)
 	/* Count again number of tapes */
 	new_max_tape_drives = get_max_tape_drives();
 
-	if ((new_max_tape_drives == 0) && (max_tape_drives == 0)) {
+	if ((new_max_tape_drives == 0) && (max_tape_drives == 0))
 		/* If there are no tape drives don't change anything */
 		return;
-        } else {
+	else {
 		if (new_max_tape_drives > max_tape_drives) {
 			/* New tapes found: Realloc structures */
 			tape_old_stats = (struct tape_stats *)
@@ -209,11 +211,11 @@ void tape_check_tapes_and_realloc(void)
 			tape_new_stats=(struct tape_stats *)
 				realloc(tape_new_stats,	sizeof(struct tape_stats) * new_max_tape_drives);
 			if ((tape_old_stats == NULL) ||	(tape_new_stats == NULL)) {
-                                if (tape_old_stats != NULL) {
+				if (tape_old_stats != NULL) {
 					free(tape_old_stats);
 					tape_old_stats = NULL;
 				}
-                                if (tape_new_stats != NULL) {
+				if (tape_new_stats != NULL) {
 					free(tape_new_stats);
 					tape_new_stats = NULL;
 				}
@@ -333,6 +335,12 @@ void tape_get_updated_stats(void)
 		TAPE_STAT_FILE_VAL(TAPE_STAT_PATH "write_cnt", write_count)
 		TAPE_STAT_FILE_VAL(TAPE_STAT_PATH "other_cnt", other_count)
 		TAPE_STAT_FILE_VAL(TAPE_STAT_PATH "resid_cnt", resid_count)
+
+		if ((tape_new_stats[i].read_time < tape_old_stats[i].read_time) ||
+		    (tape_new_stats[i].write_time < tape_old_stats[i].write_time) ||
+		    (tape_new_stats[i].other_time < tape_old_stats[i].other_time)) {
+			tape_new_stats[i].valid = TAPE_STATS_INVALID;
+		}
 	}
 }
 
@@ -386,7 +394,9 @@ void tape_calc_one_stats(struct calc_stats *stats, int i)
 		if (fp == NULL) {
 			duration = 0;
 		} else {
-			fscanf(fp, "%lf", &temp);
+			if (fscanf(fp, "%lf", &temp) != 1) {
+				temp = 0;
+			}
 			duration = (uint64_t) (temp * 1000);
 			fclose(fp);
 		}
@@ -427,8 +437,8 @@ void tape_write_stats(struct calc_stats *tape, int i)
 		" %11"PRId64" %3"PRId64" %3"PRId64" %3"PRId64
 		" %7"PRId64" %7"PRId64"\n", buffer,
 		tape->reads_per_second, tape->writes_per_second,
-		tape->kbytes_read_per_second/divisor,
-		tape->kbytes_written_per_second/divisor,
+		tape->kbytes_read_per_second / divisor,
+		tape->kbytes_written_per_second / divisor,
 		tape->read_pct_wait, tape->write_pct_wait,
 		tape->all_pct_wait, tape->resids_per_second,
 		tape->other_per_second);
@@ -504,14 +514,14 @@ void write_stats(int curr, struct tm *rectime)
 
 /*
  ***************************************************************************
- * Main loop: Read I/O stats from the relevant sources and display them.
+ * Main loop: Read tape stats from the relevant sources and display them.
  *
  * IN:
  * @count	Number of lines of stats to print.
  * @rectime	Current date and time.
  ***************************************************************************
  */
-void rw_io_stat_loop(long int count, struct tm *rectime)
+void rw_tape_stat_loop(long int count, struct tm *rectime)
 {
 	struct tape_stats *tmp;
 	int curr = 1;
@@ -676,7 +686,7 @@ int main(int argc, char **argv)
 	alarm(interval);
 
 	/* Main loop */
-	rw_io_stat_loop(count, &rectime);
+	rw_tape_stat_loop(count, &rectime);
 
 	/* Free structures */
 	tape_uninitialise();
